with
    initial_dns as (
  select *
from raw_dns
where ddate between date('2021-09-01') and date('2021-10-31')
),
timezone_adjusted_dns as (
  select
  datetime(timestamp(dtime_utc), validated_metadata_unit_timezones.timezone) as dtime,
  date(datetime(timestamp(dtime_utc), validated_metadata_unit_timezones.timezone)) as ddate,
  * except (dtime, ddate, dtime_utc, timezone)
from initial_dns
left join validated_metadata_unit_timezones using (unit_id)
where ddate between date('2021-09-01') and date('2021-10-31')
),
prefilters_dns_1 as (
  select timezone_adjusted_dns.*
from timezone_adjusted_dns
inner join unit_days_to_include using (unit_id, ddate)
),
prefilters_dns_2 as (
  select prefilters_dns_1.*
from prefilters_dns_1
inner join units_to_include using (unit_id)
),
prefilters_dns_3 as (
  select *
from prefilters_dns_2
where TRUE
),
selected_and_transformed_dns as (
  select unit_id,
  dtime,
  ddate,
  extract(hour from dtime) as hour,
  nameserver,
  lookup_host,
  response_ip,
  rtt,
  successes,
  failures
from prefilters_dns_3
),
groups_satisfying_filters_dns_1 as (
  select unit_id, ddate, hour
from selected_and_transformed_dns
group by unit_id, ddate, hour
having sum(failures) / sum(successes + failures) < 1
),
filters_dns_1 as (
  select selected_and_transformed_dns.*
from selected_and_transformed_dns
inner join groups_satisfying_filters_dns_1 using (unit_id, ddate, hour)
),
groups_satisfying_filters_dns_2 as (
  select unit_id, ddate
from filters_dns_1
group by unit_id, ddate
having sum(failures) / sum(successes + failures) <= 0.25
),
filters_dns_2 as (
  select filters_dns_1.*
from filters_dns_1
inner join groups_satisfying_filters_dns_2 using (unit_id, ddate)
)

    select * from filters_dns_2